<?php
/*
Plugin Name: Electric Studio Auto Post Expire
Plugin URI: http://www.electricstudio.co.uk
Description: Set an expiry date and time for posts
Version: 1.6.10
Author: Gabor Javorszky
Author URI: http://www.electricstudio.co.uk
License: GPL2
*/
register_activation_hook(__FILE__,array('ES_Ape_Installation','install'));
register_deactivation_hook(__FILE__,array('ES_Ape_Installation','uninstall'));



/**
 * @package ES_Ape
 * @subpackage ES_Ape_Config
 *
 * Handles versioning and other default variables (if any)
 *
 * @author Gabor Javorszky <gabor@electricstudio.co.uk>
 */
class ES_Ape_Config {
	/**
	 * Version number
	 *
	 * @var string
	 */
	private static $version = '1.6.10';

	/**
	 * Option name for the list of post types that should be allowed to expire. Corresponds to 'option_name' column in the _options table. Also, get_option( this )
	 *
	 * @var string
	 */
	private static $posttype_option_name = 'es_ape_pt';

	/**
	 * Option name for the version number of the current plugin. Corresponds to 'option_name' column in the _options table. Also, get_option( this )
	 *
	 * @var string
	 */
	private static $version_opt_name = 'es_ape_version';

	/**
	 * Enumerates all the available post types, including custom post types.
	 *
	 * @return array an array with the post types in it as values
	 */
	public static function get_available_post_types() {
		$pt_args = array(
			'public' => true
		);
		$all_posttypes = get_post_types( $pt_args, 'names' );
		return $all_posttypes;
	}

	/**
	 * Takes the database stored options, and reformats them into a sane way
	 * to use in the rest of the plugin
	 *
	 * @return array The new, improved array
	 * @since 1.6
	 */
	public static function sanitize_options() {
		$new_options = '';
		$pt_optname = self::get_opt_name( 'pt' );
		$options = get_option( $pt_optname );
		$pt = self::get_available_post_types();
		foreach ($pt as $_pt) {
			if( array_key_exists($_pt, $options ) ) {
				$new_options[ 'types' ][$_pt] = $_pt;
			}
			$new_options[ 'defaults' ][$_pt] = $options[ 'default_' . $_pt ];
			$new_options[ 'statuses' ][$_pt] = $options[ 'status_' . $_pt ];
		}
		$new_options[ 'es_ape_schedule' ] = $options[ 'es_ape_schedule' ];
		return $new_options;
	}

	/**
	 * Returns the name of an option used by the plugin, either the posttypes or version, depending on the argument passed to it
	 *
	 * @param string $what 'pt' or 'ver', otherwise it fails
	 *
	 * @return string whatever is stored in the private static variables
	 */
	public static function get_opt_name( $what ) {
		switch( $what ) {
			case 'pt':
				return self::$posttype_option_name;
				break;
			case 'ver':
				return self::$version_opt_name;
				break;
			default:
				return false;
		}
	}
}

/**
 * @package ES_Ape
 * @subpackage ES_Ape_Installation
 *
 * Handles primary database functions on activation / deactivation
 *
 * @author Gabor Javorszky <gabor@electricstudio.co.uk>
 *
 */
class ES_Ape_Installation extends ES_Ape_Config {

	/**
	 * Adds options to the _options table and prepopulates them with default data
	 *
	 * @return void database function
	 * @author Gabor Javorszky <gabor@electricstudio.co.uk>
	 */
	public static function install() {
		add_option( parent::get_opt_name( 'pt' ) , parent::get_available_post_types(), '', 'yes');
		// add_option( parent::get_opt_name( 'ver' ), parent::get_version(), '', 'yes');
		self::convert_old();
	}

	/**
	 * Converts the old settings to the new settings. If there is no old setting to convert, it just does nothing.
	 *
	 * @return void manipulates database
	 */
	private static function convert_old() {
		$expire_args = array(
			'post_type' => 'any',
			'post_status' => 'any',
			'meta_key' => '_es_expirydate'
		);

		$derp = new WP_Query( $expire_args );
		$old_opts = get_option( 'esape_posttypes' );
		if(!empty($old_opts)) {

			foreach ($old_opts as $o_opt) {
				$new_opt[ $o_opt ] = $o_opt;
			}
			update_option( parent::get_opt_name( 'pt' ), $new_opt );
		}

		if( $derp->have_posts() ) {
			while( $derp->have_posts() ) {
				$derp->the_post();
				$custom = get_post_custom();
				$newdate = strtotime( $custom[ '_es_expirydate' ][0] );
				update_post_meta( get_the_ID(), 'es_ape_expiry', $newdate );
			}
		}
	}

	/**
	 * Deletes the option from the database
	 *
	 * @return void database function
	 * @author Gabor Javorszky <gabor@electricstudio.co.uk>
	 */
	public static function uninstall() {
		wp_clear_scheduled_hook( 'es_ape_cronz' );
		delete_option( parent::get_opt_name( 'pt' ) );
    	delete_option( parent::get_opt_name( 'ver' ) );
	}
}

/**
 * @package ES_Ape
 * @subpackage ES_Settings
 *
 * @author Gabor Javorszky <gabor@electricstudio.co.uk>
 */
class ES_Settings extends ES_Ape_Config {

	/**
	 * Hooks scripts into place, so it gets the ball rolling (builds the option pages, and registers the settings we want to manage)
	 */
	function __construct(){
		add_action('admin_menu', array( $this , 'es_ape_admin_menu' ) );
		add_action('admin_init', array( $this , 'es_ape_register_settings' ) );
		add_shortcode('expirydate', array( $this, 'expiry_date_shortcode' ) );
	}

	/**
	 * Adds the administration page for the settings
	 *
	 * @return void builtin Wordpress functionality
	 */
	function es_ape_admin_menu() {
		add_options_page( 'Post Expiry', 'Post Expiry', 'manage_options', 'es_ape_options_page', array( $this, 'add_settings_page') );
	}


	/**
	 * Is called from admin_menu() from within add_options_page
	 * basically outputs all the html that we need
	 */
	function add_settings_page() {
		?>
		<div class="wrap">
			<form action="options.php" method="post" id="es_expiry">
				<div class="electric-studio-logo"><br /></div><h2>Electric Studio Auto Post-expiry plugin settings</h2>
				<?php
				$opt_g = parent::get_opt_name( 'pt' );
				settings_fields( $opt_g ); // has to be the same as register settings' first argument!!!!
				do_settings_sections( 'es_ape_options_page' );
				?>
				<input name="Submit" type="submit" value="<?php esc_attr_e('Save Changes'); ?>" class="button-primary" />
			</form>
		</div>
		<?php
	}


	/**
	 * Registers settings, and outputs fields (html) to the option page
	 *
	 * @return html fields, inputs, nonces, etc
	 */
	function es_ape_register_settings() {
		$pt_optname = parent::get_opt_name( 'pt' );
		register_setting( $pt_optname, $pt_optname );
		add_settings_section( $pt_optname, '', array( $this, 'settings_page_content' ), 'es_ape_options_page' );
		add_settings_field( 'some_id', 'Select what content should be expirable', array( $this, 'settings_field_content' ), 'es_ape_options_page', $pt_optname );
		add_settings_field( 'frequency', 'How frequently should the site check for expired content?', array( $this, 'settings_field_content_expiry' ), 'es_ape_options_page', $pt_optname );
	}

	/**
	 * Adds the scheduling frequency option to the plugin.
	 *
	 * @return html The select form element
	 */
	function settings_field_content_expiry() {
		$pt_optname = parent::get_opt_name( 'pt' );
		$pt = parent::get_available_post_types();
		$options = get_option( $pt_optname );
		$schedule_opt = (array_key_exists('es_ape_schedule', $options)) ? $options[ 'es_ape_schedule' ]: '';
		$schedules = wp_get_schedules();


		$html = '<label for="es_ape_pt[es_ape_schedule]">';
		$html .= '<select id="es_ape_pt[es_ape_schedule]" name="es_ape_pt[es_ape_schedule]">';

		foreach ($schedules as $schedule => $ray ) {
			$sel = ( $schedule_opt == $schedule ) ? ' selected="selected"':'';
			$html .= '<option value="' . $schedule . '"' . $sel . '>' . $ray['display'] . '</option>';
		}
		$html .= '</select></label>';
		echo $html;
	}

	/**
	 * This is the actual content for the setting field. Is called from es_ape_register_setting.
	 * Handles the html for the checkboxes
	 *
	 * @return html
	 */
	function settings_field_content()  {
		$pt_optname = parent::get_opt_name( 'pt' );
		$pt = parent::get_available_post_types();
		$options = get_option( $pt_optname );
		global $wp_post_statuses;
		$ps = $wp_post_statuses;
		$unset = array( 'publish', 'auto-draft', 'inherit' );
		foreach ($unset as $_u ) {
			unset( $ps[$_u] );
		}

		?>
		<div class="a_row a_header">
			<div class="a_col-1">
				<h2>Post Types</h2>
				<p>If unchecked, all the other settings won't take effect.</p>
			</div>
			<div class="a_col-1 white">
				<h2>Status</h2>
				<p>After expiration, what should they be set as?</p>
			</div>
			<div class="a_col-3">
				<h2>Default exp. time</h2>
				<p>If you want a default expiration time, set it here (from publish date). Click on the number field to delete the default expiration time (will not expire on its own)</p>
			</div>
		</div>

		<?php

		$html = '';
		// Run this for each post type
		foreach ( $pt as $_pt ) {
			// if(array_key_exists($_)pt)
			$checked = (array_key_exists($_pt, $options)) ? ' checked="checked"' : '';
			$status = (array_key_exists('status_' . $_pt, $options)) ? $options['status_' . $_pt] : 'draft';
			$default = (array_key_exists('default_' . $_pt, $options)) ? $options['default_' . $_pt] : 604800;




			// let's set up the name of the option we're going to save it into
			$name = '"' . $pt_optname . '[' . $_pt . ']"'; // true/false for the posttype
			$status_n = '"' . $pt_optname . '[status_' . $_pt . ']"'; // status name for the default status of the post type in question
			$default_n = '"' . $pt_optname . '[default_' . $_pt . ']"'; // default time (in time()) for the post type in question

			$html .= '<div class="a_row">';
			/**
			 * Let's construct the content of the actual row for each post types
			 *
			 * The first bit is the checkbox + post type name
			 */
			$html .= '<div class="a_col-1">';
			$html .= '<label for=' . $name . '>';
			$html .= '<input type="checkbox" id=' . $name . ' name=' . $name . ' value="' . $_pt . '"' . $checked . ' />'. ucfirst( $_pt );
			$html .= '</label>';
			$html .= '</div>';


			/**
			 * The second bit is the dropdown for the post
			 * status to change to once expiry time has been exceeded
			 */
			$html .= '<div class="a_col-1 white">';
			$html .= '<label for=' . $status_n . '>';
			$html .= '<select id=' . $status_n . ' name=' . $status_n . '>';

			foreach ($ps as $_ps => $k_ps) {
				$sel = ( $_ps == $status ) ? ' selected="selected"':'';
				$html .= '<option value="' . $_ps . '"' . $sel . '>' . ucfirst( $_ps ) . '</option>';
			}
			$html .= '</select></label>';
			$html .= '</div>';


			/**
			 * The third bit is for the set default expiry time dropdown bits
			 */
			$html .= '<div class="a_col-3">';
			$html .= '<label for="pt_weeks">';
			// The weeks
			$html .= '<select class="pt_weeks" id="pt_weeks_' . $_pt . '" name="pt_weeks_' . $_pt . '">';
			for ($i=51; $i > -1 ; $i-- ) {
				$html .= '<option value="' . $i . '">' . $i . '</option>';
			}
			$html .= '</select>';
			$html .= 'weeks</label>';

			// the days
			$html .= '<label for="pt_days">';
			$html .= '<select class="pt_days" id="pt_days_' . $_pt . '" name="pt_days_' . $_pt . '">';
			for ($i=6; $i > -1 ; $i-- ) {
				$html .= '<option value="' . $i . '">' . $i . '</option>';
			}
			$html .= '</select>';
			$html .= 'days</label>';

			// And the hidden / readonly field to display the time() bit (using jquery)
			$html .= '<label><input type="text" readonly="readonly" name=' . $default_n . ' id=' . $default_n . ' class="pt_timestamp" value="' . $default . '"></label>';

			$html .= '</div>';
			$html .= '</div>';

		}
		echo $html;
	}

	/**
	 * Has to be there, otherwise add_settings_section fails in es_ape_register_settings
	 * Void, because we don't actually want anything to appear
	 *
	 * @return void
	 */
	function settings_page_content() {
		$pt_optname = parent::get_opt_name( 'pt' );
		$pt = parent::get_available_post_types();
		$options = get_option( $pt_optname );
		if(array_key_exists('es_ape_schedule', $options)) {
			$schedule_opt = $options[ 'es_ape_schedule' ];
		} else {
			$schedule_opt = 'fifteenmins';
		}

		$schd = wp_get_schedule( 'es_ape_cronz' );


		if( isset( $_GET['settings-updated']) &&  $schd != $schedule_opt ) {
			wp_clear_scheduled_hook( 'es_ape_cronz' );
			wp_schedule_event( time(), $schedule_opt, 'es_ape_cronz' );
		}

		$next = wp_next_scheduled( 'es_ape_cronz' );

		?>

		<?php
		if( $next > 600000 ) {
			?>
			<h2>Next scheduled check runs on <strong> <?php echo date( 'l, jS F, Y', $next ); ?> at <?php echo date( 'H:i', $next); ?> GMT</strong>, or in about <strong><?php echo floor(($next - time()) / 60); ?></strong> minutes</h2>
			<?php
		}
	}

	/**
	 * @method		: esape_get_expiry_date_shortcode
	 * Purpose 		: To echo the expiry date of a post. For use with a shortcode
	 * @param		: $atts - extracted with shortcode_atts, only one attribute is speicified and that is format (string like format in the PHP date function).
	 * @return		: Echos date is the specified format (d-M-Y by default)
	 */
	function expiry_date_shortcode( $atts ){

		extract( shortcode_atts( array(
			'format' => 'd-M-Y',
		), $atts ) );

	    return self::get_expiry_date($format);
	}

	/**
	 * @method		: esapce_get_expiry_date()
	 * Purpose		: To return the expiry date of a post (Only to be used within the Wordpress Loop)
	 * @param		: $format - optional (default 'd-M-Y') - The format of the date (string like format in the PHP date function).
	 * @return		: date (as string)
	 */
	function get_expiry_date($format = 'd-M-Y'){
	    global $post;
	    $ts = get_post_meta($post->ID, "es_ape_expiry", true);

	    if( $ts !== '' ) {
	    	$date = date($format, $ts);
	    	return $date;
	    } else {

	    	return;
	    }
	}

	public function get_time_left() {
		global $post;
		$pt = get_post_type();
		$pt_optname = parent::get_opt_name( 'pt' );
		$options = get_option( $pt_optname );
		$schedule = wp_get_schedules();
		$step = $schedule[$options['es_ape_schedule']]['interval'];
		$next = wp_next_scheduled( 'es_ape_cronz' );
		$ts = get_post_meta($post->ID, "es_ape_expiry", true);
		$post_date = strtotime($post->post_date);
		if( $ts !== '') {
			return human_time_diff(time(), intval($ts));
		} elseif( $options['default_' . $pt] !== '' && $options['default_' . $pt] > 0) {
			$expire = $post_date + $options['default_' . $pt];
			$ceiling = self::get_time_ceiling($expire, $next, $step);

			$timeleft = human_time_diff(time(), $ceiling);
			return $timeleft;
		}
		return false;
	}


	/**
	 * Returns when the post will actuall expire. Takes into account the expiration date set and
	 * the frequency of crons run.
	 * @param  integer $postdate the date the post was published
	 * @param  integer $next     the time when next cron is run
	 * @param  integer $step     the frequency with which the cron is run
	 * @return integer           when the post will actually expire
	 */
	public function get_time_ceiling($expire, $next, $step) {
		if(($next - $step) < $expire) {
			return $next;
		}
		$tte = $next - $expire;
		$steps = ceil($tte / $step);
		return $next + ($steps * $step);
	}
}

/**
 * @package ES_Ape
 * @subpackage ES_Metabox
 *
 * Adds the necessary metaboxes to the post types that have been selected. Uses ES_Settings
 */
class ES_Metabox extends ES_Ape_Config {

	/**
	 * Only runs if it's an admin request. Hooks all the other necessary bits in place
	 */
	function __construct() {
		if( is_admin() ) {
			add_action( 'admin_init', array( $this, 'the_metabox' ) );
			add_action( 'admin_print_styles', array( $this, 'es_ape_styles' ) );
			add_action( 'admin_print_scripts', array( $this, 'es_ape_scripts' ) );
			add_action( 'save_post', array( $this, 'es_ape_save_post' ) );
		}
	}

	/**
	 * Registers and enqueues the custom css for the administration page
	 *
	 * @return html link in header to css file
	 */
	function es_ape_styles() {
		$url = plugins_url( '', __FILE__ ) . '/css/';

		wp_register_style( 'es_ape_dp', $url . 'jquery-ui-1.9.0.custom.min.css' );
		wp_register_style( 'es_ape_css', $url . 'es_ape.css' );
		wp_enqueue_style( 'es_ape_dp' );
		wp_enqueue_style( 'es_ape_css' );
	}

	/**
	 * Runs when the "Update" or "Publish" button is hit on the edit post screen.
	 * Saves new metadata.
	 *
	 * @param int $post_id ID of the post we're saving
	 *
	 * @return void database manipulation
	 */
	function es_ape_save_post( $post_id) {
		global $current_user, $post_type;

		$post_type_object = get_post_type_object( $post_type );
		if( ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )
			|| wp_is_post_revision( $post_id )
			|| !isset( $_POST['post_ID'] )
			|| $post_id != $_POST['post_ID']
			|| !current_user_can( $post_type_object->cap->edit_post, $post_id )
			) {

			return;
		}

		if( !wp_verify_nonce( $_POST[ 'es_ape_nonce' ], parent::get_opt_name( 'pt' ) ) ) {
			// wp_die( '<h1>Whoa, something is not right...</h1><p>Your nonce didn\'t verify... can you hurl this log to the developer at gabor@electricstudio.co.uk please?</p>' . es_preit(  $_POST[ 'es_ape_nonce' ], true ) );
			return;
		}

		if( $_POST[ 'es_ape_date' ] !== '' ) {
			$ts_str = $_POST['es_ape_date'] . ' ' . $_POST['es_ape_hour'] . ':' . $_POST['es_ape_minute'];
			$ts = strtotime( $ts_str );
			update_post_meta( $post_id, 'es_ape_expiry', $ts );
		} else {
			delete_post_meta( $post_id, 'es_ape_expiry' );
		}
	}

	/**
	 * Provides sanitization. Timestamp -> strings for the jquery ui plugin, plus the dropdowns
	 * for the hour and the minute.
	 *
	 * @param int $ts unix timestamp (the kind you get with time())
	 *
	 * @return array|string assoc array of different elements, or an empty string
	 */
	function es_ape_date(  $ts ) {
		if( $ts != '' ) {
			$jq_hour = date( 'G', $ts);
			$jq_minute = date( 'i', $ts );
			$jq_date = date( 'n/d/Y', $ts );
			$jq_tz = date( 'Z', $ts );
			$jq = array( $jq_hour, $jq_minute, $jq_date, $jq_tz );
		} else {
			$jq = '';
		}
		return $jq;
	}

	/**
	 * Registers and enqueues scripts needed for the plugin to work
	 * jquery-ui-datepicker is builtin
	 *
	 * @return html links in the header
	 */
	function es_ape_scripts() {
		$url = plugins_url( '', __FILE__ );

		wp_enqueue_script( 'jquery-ui-datepicker' );
		wp_register_script( 'es_ape_func', $url . '/es_ape.js', 'jquery-ui-datepicker' );
		wp_enqueue_script( 'es_ape_func' );
	}

	/**
	 * Outputs the metaboxes. Calls a different function to write the html.
	 * Depends on the settings of the plugin.
	 *
	 * @return html Meta box on post types in the top right corner
	 */
	public function the_metabox() {
		$pt_optname = parent::get_opt_name( 'pt' );
		$pt = self::get_available_post_types();

		$options = get_option( $pt_optname );
		// wp_die( es_preit( array( $options ), false ) );
		$enabled_posttypes = array_intersect($pt, $options);

		if( is_array( $enabled_posttypes ) ) {

			foreach ($enabled_posttypes as $pt) {
				add_meta_box( 'es_ape_settings', 'Expire the content', array( &$this, 'the_metabox_html' ), $pt, 'side', 'high' );
			}
		}

	}

	/**
	 * The metabox html. Allows you to select the date and time.
	 *
	 * @return html the metabox
	 */
	function the_metabox_html() {
		$custom = get_post_custom();
		$form_values = null;

		if(array_key_exists('es_ape_expiry', $custom)) {
			$form_values = self::es_ape_date( $custom[ 'es_ape_expiry' ][0] );
		}

		if(empty($form_values)) {
			$form_values = array('',0,0);
		}

		$time_value = self::es_ape_date( time() );
		$local_time_value = self::es_ape_date( current_time( 'timestamp' ) );
		wp_nonce_field( parent::get_opt_name( 'pt' ), 'es_ape_nonce' );
		?>
		<p>To remove the expiration on the content, just delete the value in the datefield (select all, and hit the delete key), and click "Update"</p>

		<label for="es_ape_datefield">
			<p>Select the date:</p>
			<input type="text" id="es_ape_datefield" name="es_ape_date" value="<?php echo $form_values[2]; ?>">

		</label>
		<label for="es_ape_hour">
			<p>Hour</p>
			<select name="es_ape_hour" id="es_ape_hour">
				<?php
				for ( $i = 0; $i < 24 ; $i++ ) {
					$selected = ( intval($form_values[0]) === $i ) ? ' selected="selected"' : '';
					echo '<option value="' . $i . '"' . $selected . '>' . $i . ':00</option>';
				}
				?>
			</select>
		</label>
		<label for="es_ape_minute">
			<p>Minute</p>
			<select name="es_ape_minute" id="es_ape_minute">
				<?php
				for ( $i = 0; $i < 4 ; $i++ ) {
					$selected = ( intval($form_values[1]) === $i * 15 ) ? ' selected="selected"' : '';
					echo '<option value="' . $i * 15 . '"' . $selected . '>' . $i * 15 . '</option>';
				}
				?>
			</select>
		</label>
		<?php
	}
}


/**
 * @package ES_Ape
 * @subpackage ES_Expire
 *
 * Logic to hide posts if they are set to expire
 */
class ES_Expire extends ES_Ape_Config {

	/**
	 * Hook the logic into init, otherwise fails (way too early to run)
	 */
	function __construct() {

		/**
		 * @version 1.6
		 * Hooking into init no longer necessary, as it's run by a cron job
		 * Which means, soon as the cron happens, it needs to run. Need to
		 * see about dependencies though.
		 */
		// add_action( 'init', array( $this, 'es_ape_expire' ) );

		/**
		 * This needed to be moved out of here, since it will not be available
		 * for the general masses when the cron is run.
		 */
		// add_shortcode('expirydate', array( $this, 'expiry_date_shortcode' ) );

		/**
		 * Instead this needs to be run, so expiration actually happens
		 */
		self::es_ape_expire();

	}

	/**
	 * Get all the posts that should expire. And expire them.
	 *
	 * @return void database manipulation
	 */
	function es_ape_expire() {
		// Get the options in a sane, sanitized way
		$options = parent::sanitize_options();

		// Get the current time here, so we don't have to recalculate this many times (unnecessary)
		$ct = current_time( 'timestamp' );

		// Loop over all the available post types
		foreach ($options['types'] as $pt) {

			// We only want to expire published, future or pending articles

			$expire_args = array(
				'post_type' => $pt,
				'post_status' => array( 'publish', 'future', 'pending' ),
			);
			$derp = new WP_Query( $expire_args );

			// Run the loop for each post type
			if( $derp->have_posts() ) {
				while( $derp->have_posts() ) {
					$derp->the_post();
					global $post;

					$custom = get_post_custom();

					// If the expiry field is there, check if it expired ( current time is greater than when it's supposed to go off )
					if( isset( $custom[ 'es_ape_expiry' ][ 0 ] ) && $custom[ 'es_ape_expiry' ][ 0 ] != '' &&  $ct > $custom[ 'es_ape_expiry' ][ 0 ] ) {

						$current_status = get_post_status();
						$new_status = $options[ 'statuses' ][ $pt ];

						if( $new_status == 'trash' ) {
							wp_trash_post( $post->ID );
						} else {
							wp_transition_post_status( $new_status, $current_status, $post );
						}


						// Expire that thing!
						// $update_args = array(
						// 	'ID' => get_the_ID(),
						// 	'post_status' => $options[ 'statuses' ][ $pt ]
						// );
						// wp_update_post( $update_args );

					// Otherwise if the expiry is NOT set on the article, AND there is a default expiration set, AND that already expired, run this
					} elseif(
					         !isset( $custom[ 'es_ape_expiry' ][ 0 ] )
					         && isset( $options[ 'defaults' ][ $pt ] )
					         && $options[ 'defaults' ][ $pt ] != ''
					         && $ct > ( strtotime( $post->post_date ) + $options[ 'defaults' ][ $pt ] )
					) {

						$current_status = get_post_status();
						$new_status = $options[ 'statuses' ][ $pt ];

						if( $new_status == 'trash' ) {
							wp_trash_post( $post->ID );
						} else {
							wp_transition_post_status( $new_status, $current_status, $post );
						}

						// $update_args = array(
						// 	'ID' => get_the_ID(),
						// 	'post_status' => $options[ 'statuses' ][ $pt ]
						// );
						// wp_update_post( $update_args );
					}
				}
			}
			wp_reset_query();
		}
	}
}

/**
 * Mad props for MonkeyPress on spotting this bug.
 *
 * @param [type] $schedules [description]
 */
function add_crons( $schedules ) {
	$schedules[ 'fifteenmins' ] = array(
       'display' => __( 'Every 15 minutes' ),
       'interval' => 900
	);
	$schedules[ 'halfhour' ] = array(
       'display' => __( 'Every half hour' ),
       'interval' => 1800
	);

	$schedules[ 'fourdaily' ] = array(
		'display' => __( 'Four times a day' ),
		'interval' => 21600
	);
	return $schedules;
}
add_filter( 'cron_schedules', 'add_crons' );

$es_set = new ES_Settings;
$es_ape = new ES_Metabox;

function es_ape_exp_date( $format = 'd-M-Y', $echo = true ) {
	global $es_set;
	$date = $es_set->get_expiry_date( $format );

	if($echo) {
		echo $date;
	} else {
		return $date;
	}
}


function es_time_left() {
	global $es_set;
	return $es_set->get_time_left();

}



add_action( 'es_ape_cronz', 'the_scheduling' );
function the_scheduling() {
	$es_exp = new ES_Expire;
}


if( !function_exists('es_preit') ) {
	function es_preit( $obj, $echo = true ) {
		if( $echo ) {
			echo '<pre>';
			print_r( $obj );
			echo '</pre>';
		} else {
			return '<pre>' . print_r( $obj, true ) . '</pre>';
		}
	}
}



